@@ -7,11 +7,11 @@ def reset():
     nl.clps.clips.Clear()
     reload(nl.clps.clips)
     reload(nl.clps)
-    reload(nl.thing)
-    reload(nl.state)
-    reload(nl.prop)
     reload(nl.arith)
     reload(nl.time)
+    reload(nl.state)
+    reload(nl.thing)
+    reload(nl.prop)
     reload(nl.rule)
     reload(nl.kb)
     reload(nl)
@@ -206,3 +206,20 @@ class cms3_test(object):
         assert nl.kb.ask(nl.Fact(self.cms.Document('cpu3'),
                                  self.cms.Has(what=self.cms.Status('public')),
                                  nl.Instant('now')))
+
+        cpu3 = nl.kb.ask_obj(nl.Thing('cpu3'))
+        nl.log.logger.info(str(cpu3))
+
+
+class physics_test(object):
+    def setup(self):
+        from nl.examples import physics22
+        self.p = physics22
+
+    def teardown(self):
+        reset()
+        del self.p
+
+    def first_test(self):
+        fact = nl.kb.ask_obj(nl.Fact(self.p.Body('c1'), self.p.HasPosition(x='X2', y='X3'), 50))
+        assert str(fact[0]) == 'c1 hasposition y 57.641201061 x -65.0657847679 at 50.0'
